@@ -37,7 +37,7 @@ def get_form(cls, form_data, update=False):
         text_field = TextField()
         setattr(HavaianaForm, field, text_field)
     for key, value in cls.relations.items():
-        choices = [(obj.primary_key, str(obj)) for obj in  value[0].all()]
+        choices = [(obj.primary_key, obj) for obj in  value[0].all()]
         text = value[1].replace("_", "  ").capitalize()
         text_field = SelectField(text, choices=choices)
         setattr(HavaianaForm, key, text_field)
